@@ -1,9 +1,11 @@
 package Catmandu::Importer::PICA;
-# ABSTRACT: Package that imports PICA+ XML data
-our $VERSION = '0.02'; # VERSION
+
+# ABSTRACT: Package that imports PICA+ data
+our $VERSION = '0.03'; # VERSION
 
 use Catmandu::Sane;
 use Catmandu::PICA;
+use Catmandu::PICAplus;
 use Moo;
 
 no if $] >= 5.018, 'warnings', "experimental::smartmatch";
@@ -14,13 +16,16 @@ has type => ( is => 'ro', default => sub {'XML'} );
 
 sub pica_generator {
     my $self = shift;
-    
+
     my $file;
 
     given ( $self->type ) {
-        when ('XML') {          
+        when ('XML') {
             $file = Catmandu::PICA->new( $self->fh );
         }
+        when ('PICAplus') {
+            $file = Catmandu::PICAplus->new( $self->fh );
+        }
         die "unknown";
     }
 
@@ -36,15 +41,18 @@ sub generator {
     my $type = $self->type;
 
     given ($type) {
-        when (/^XML$/) {
+        when ('XML') {
             return $self->pica_generator;
         }
-        die "need PICA+ XML data as input";
+        when ('PICAplus') {
+            return $self->pica_generator;
+        }
+        die "need PICA+ data as input";
     }
 }
 
 
-1; # End of Catmandu::Importer::PICA
+1;    # End of Catmandu::Importer::PICA
 
 __END__
 
@@ -52,11 +60,11 @@ __END__
 
 =head1 NAME
 
-Catmandu::Importer::PICA - Package that imports PICA+ XML data
+Catmandu::Importer::PICA - Package that imports PICA+ data
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -110,7 +118,7 @@ Parse PICA XML to native Perl hash containing two keys: '_id' and 'record'.
 =head2 new(file => $filename,type=>$type)
 
 Create a new PICA importer for $filename. Use STDIN when no filename is given. Type 
-describes the sytax of the PICA records. Currently we support: PICA+ XML.
+describes the sytax of the PICA records. Currently we support following types: PICAplus, XML.
 
 =head2 count
 
@@ -127,7 +135,7 @@ L<Catmandu::Iterable>
 
 =head1 AUTHOR
 
-Johann Rolschewski
+Johann Rolschewski <rolschewski@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
